==> vikiwiki2-1.9.7.14.zip: vikiwiki2/vikiwiki/msg/en.rb <==
{
# File Error
:FILE_ALREADY_MODIFIED => "File is already modified.",
:FILE_AREADY_EXISTS => "File already exists. %1",
:FILE_NOT_FOUND => "File or directory not found. %1",
:FILE_ALREADY_CHECKOUT => "File is already checked out.",
:FILE_NOT_CHECKOUT => "File is not checked out.",
:FILE_NOT_SPECIFIED => "Fie name is not specified.",
:FILE_INVALID_NAME => "Path name has invalid character. %1",
:FILE_FULL_PATH_DENIED => "Full path specification can not be used.",
:FILE_INVALID_EXTENTION => "Invalid extension is specified.",
:NOT_A_DIRECTORY => "It is not a directory. %1",
:NOT_A_FILE => "It is not a file. %1",
# Page Error
:PAGE_INVALID_PATH => "Page path is invalid. %1",
:PAGE_INVALID_NAME => "Page name is invalid. %1",
:PAGE_NAME_TOO_LONG => "Length og page name is too long. %1",
:PAGE_ALREADY_EXISTS => "Page already exists. %1",
:PAGE_NOT_FOUND => "Page is not found. %1",
:LAYOUT_PAGE_NOT_FOUND => "Page for layout is not found. %1",
:PAGE_STATIC_DENIED => "The static HTML of the page %1 which an authentication requires is not generated.",
# Authentication Error
:AUTH_FAILED => "Failure to authenticate.",
# Function Error
:FUNC_LINK_GEN_ERROR => "Links is not generated for %1.",
:FUNC_THEME_NOT_LOCAL => "The theme is not a local file.",
:FUNC_THEME_ELM_NOT_FOUND => "The theme doesn't have the specified element. %1",
:FUNC_THEME_URI_INVALID_PROTCOL => "The specified protocol is invalid.",
:FUNC_THEME_ESCAPE_DENIED => "Escape character is not able to be used in style text.",
:FUNC_THEME_COMMENT_DENIED => "Comment is not able to be concluded in style text.",
:FUNC_THEME_INVALID_KEYWORD => "Invalid word exists.",
:FUNC_DIV_INVALID_CLASS => "Invalid class is specified.",
:FUNC_PLUGIN_NOT_FOUND => "Pugin %1 not found.%2",
:FUNC_DUPLICATE_IMPORT => "Can not import the imported page.",
}

==> vikiwiki2-1.9.8.0.zip: vikiwiki2/vikiwiki/msg/en.rb <==
{
# File Error
:FILE_ALREADY_MODIFIED => "File is already modified.",
:FILE_AREADY_EXISTS => "File already exists. %1",
:FILE_NOT_FOUND => "File or directory not found. %1",
:FILE_ALREADY_CHECKOUT => "File is already checked out.",
:FILE_NOT_CHECKOUT => "File is not checked out.",
:FILE_NOT_SPECIFIED => "Fie name is not specified.",
:FILE_INVALID_NAME => "Path name has invalid character. %1",
:FILE_FULL_PATH_DENIED => "Full path specification can not be used.",
:FILE_INVALID_EXTENTION => "Invalid extension is specified.",
:NOT_A_DIRECTORY => "It is not a directory. %1",
:NOT_A_FILE => "It is not a file. %1",
# Page Error
:PAGE_INVALID_PATH => "Page path is invalid. %1",
:PAGE_INVALID_NAME => "Page name is invalid. %1",
:PAGE_NAME_TOO_LONG => "Length og page name is too long. %1",
:PAGE_ALREADY_EXISTS => "Page already exists. %1",
:PAGE_NOT_FOUND => "Page is not found. %1",
:LAYOUT_PAGE_NOT_FOUND => "Page for layout is not found. %1",
:PAGE_STATIC_DENIED => "The static HTML of the page %1 which an authentication requires is not generated.",
:PAGE_INVALID_WORD => "Your text includes the invalid words.",
# Authentication Error
:AUTH_FAILED => "Failure to authenticate.",
# Function Error
:FUNC_LINK_GEN_ERROR => "Links is not generated for %1.",
:FUNC_THEME_NOT_LOCAL => "The theme is not a local file.",
:FUNC_THEME_ELM_NOT_FOUND => "The theme doesn't have the specified element. %1",
:FUNC_THEME_URI_INVALID_PROTCOL => "The specified protocol is invalid.",
:FUNC_THEME_ESCAPE_DENIED => "Escape character is not able to be used in style text.",
:FUNC_THEME_COMMENT_DENIED => "Comment is not able to be concluded in style text.",
:FUNC_THEME_INVALID_KEYWORD => "Invalid word exists.",
:FUNC_DIV_INVALID_CLASS => "Invalid class is specified.",
:FUNC_PLUGIN_NOT_FOUND => "Pugin %1 not found.%2",
:FUNC_DUPLICATE_IMPORT => "Can not import the imported page.",
:FUNC_NOT_SUPPORTED => "Function %1 is not supported.",
}
